// pages/login/login.js
import { API_LOGIN } from '../../const/apiurl'
var app = getApp();
Page({

  /**
   * 页面的初始数据
   */
  data: {
    account:'',
    password:'',
    errMsg:'',
    loginDisabled:true
  },
  /**
   *  账号输入
   * @param {}} e 
   */
  bindAccountInput: function (e) {
    this.setData({
      account : e.detail.value,
      errMsg:''
    })
    this.updateSubmitState();
  },
  /**
   *  密码输入
   * @param {*} e 
   */
  bindPasswordInput: function (e) {
    this.setData({
      password: e.detail.value,
      errMsg:''
    })
    this.updateSubmitState();
  },
  
  /**
   * 登录
   */
  formSubmit(e) {
    if(this.data.account == '' || this.data.password == ''){
      this.setData({
        errMsg:"账号或密码为空"
      })
      return
    }
    this.login(e.detail.value);
  },

  /**
   * 刷新submit按钮 
   * @param {} params 
   */
   updateSubmitState(){
    if(this.data.account == '' || this.data.password == ''){
      this.setData({
        loginDisabled:true
      })
    }else{
      this.setData({
        loginDisabled:false
      })
    }
   },

   /**
    * 清除账号
    * @param {*} params 
    */
   clearAccount(){
    this.setData({
      account:""
    })
   },

    /**
    * 清除密码
    * @param {*} params 
    */
   clearPassword(){
    this.setData({
      password:""
    })
  },

  /**
   * 登录
   * @param {}} options 
   */
  login(params){
    wx.showLoading({
      title: '请稍后...',
    })
    wx.request({
      url: app.globalData.BASE_URL+API_LOGIN,
      data: {
        username: params.username,
        password: params.password
      },
      method: 'POST',
      header: {
        'content-type': 'application/json' // 默认值
      },
      success (res) {
        wx.hideLoading({
          success: (res) => {},
        })
        if (res.data.code == 200) {
          wx.showToast({
            title: '登录成功',
            icon: 'success',
            duration: 2000
          })
          wx.setStorageSync('accountInfo', params)
          //登录信息 =》 全局变量
          getApp().globalData.localAccountInfo =  res.data; 
          wx.redirectTo({
            url: '/pages/home/home',
          })
        }else{
          wx.showToast({
            title: res.data.msg,
            icon: 'none',
            duration: 2000
          })
        }
      },
      fail(e){
        wx.hideLoading({
          success: (res) => {},
        })
        wx.showToast({
          title: e,
          icon: 'none',
          duration: 2000
        })
        console.log(e)
      }
    })
  },


  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {

  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady: function () {
    var accountInfo = wx.getStorageSync('accountInfo') || []
    if(accountInfo != null){
      this.setData({
        account:accountInfo.username,
        password:accountInfo.password,
        loginDisabled:false
      })
      this.login(accountInfo)
    } 
  },

 
 
 
})